@@ -4,7 +4,7 @@
  *
  * PHP Version 5
  *
- * Copyright (c) 2008-2015, Manuel Pichler <mapi@pdepend.org>.
+ * Copyright (c) 2008-2017 Manuel Pichler <mapi@pdepend.org>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,7 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 
@@ -49,7 +49,7 @@ use PDepend\Util\Cache\CacheDriver;
  *
  * Callable objects is a generic parent for methods and functions.
  *
- * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 abstract class AbstractASTCallable extends AbstractASTArtifact implements ASTCallable
@@ -261,7 +261,9 @@ abstract class AbstractASTCallable extends AbstractASTArtifact implements ASTCal
     public function getDependencies()
     {
         return new ASTClassOrInterfaceReferenceIterator(
-            $this->findChildrenOfType('PDepend\\Source\\AST\\ASTClassOrInterfaceReference')
+            $this->findChildrenOfType(
+                'PDepend\\Source\\AST\\ASTClassOrInterfaceReference'
+            )
         );
     }
 
